"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapJSX = void 0;
const react_1 = __importDefault(require("react"));
const escapeRegExp_1 = __importDefault(require("lodash/escapeRegExp"));
/**
 *
 * Wraps every instance of `wrap` found in `str` in the provided `element`.
 *
 * E.g. `wrapJSX('Apple', 'ap', 'em') => <em>Ap</em>ple`
 *
 * @param str
 * @param wrap
 * @param element
 * @returns `JSX.Element`
 * @internal
 */
const wrapJSX = (str, wrap, element) => {
    if (wrap && element) {
        const cleanWrap = (0, escapeRegExp_1.default)(wrap);
        const regex = new RegExp(cleanWrap, 'gi');
        const matches = str.matchAll(regex);
        if (matches) {
            const outArray = str.split('');
            /**
             * For every match, splice it into the "string",
             * wrapped in the React element
             */
            // Consider adding --downlevelIteration TS flag so we don't need Array.from
            for (const match of Array.from(matches)) {
                const matchIndex = match.index ?? -1;
                const matchContent = match[0];
                const matchLength = matchContent.length;
                const key = matchIndex + matchContent + matchLength;
                // We create a replacement array that's
                // the same length as the match we're deleting,
                // in order to keep the matchIndexes aligned
                // with the indexes of the output array
                const replacement = new Array(matchLength).fill('');
                replacement[0] = react_1.default.createElement(element, { key }, matchContent);
                outArray.splice(matchIndex, matchLength, ...replacement);
            }
            return react_1.default.createElement(react_1.default.Fragment, null, outArray);
        }
        return react_1.default.createElement(react_1.default.Fragment, null, str);
    }
    return react_1.default.createElement(react_1.default.Fragment, null, str);
};
exports.wrapJSX = wrapJSX;
//# sourceMappingURL=wrapJSX.js.map